@@ -1,4 +1,4 @@
-/* $Id: value.cc 1050 2007-03-20 23:51:35Z arminb $ */
+/* $Id: value.cc 1083 2007-06-20 13:57:08Z murrayc $ */
 // -*- C++ -*- //
 
 /* value.cc
@@ -317,7 +317,8 @@ Glib::Date Value::get_date() const
 
 void Value::set(const Glib::Date& val)
 {
-  value_reinit(gobj(), Glib::Value<Glib::Date>::value_type());
+  //There is no Glib::Value<> specialization, so we explicitly mention G_TYPE_DATE: value_reinit(gobj(), Glib::Value<Glib::Date>::value_type());
+  value_reinit(gobj(), G_TYPE_DATE);
   g_value_set_boxed(gobj(), val.gobj());
 }
 
@@ -370,7 +371,7 @@ const GdaNumeric* Value::get_numeric() const
 
 void Value::set(const GdaNumeric * val)
 {
-  gda_value_set_numeric(gobj(), val); 
+  gda_value_set_numeric(gobj(), val);
 }
 
 float Value::get_float() const
@@ -456,7 +457,7 @@ GType Value::get_g_type() const
   return g_value_get_gtype(gobj());
 }
 
-void Value::set(GType val)
+void Value::set_g_type(GType val)
 {
   value_reinit(gobj(), G_TYPE_GTYPE);
   g_value_set_gtype(gobj(), val);
@@ -541,7 +542,7 @@ const GType VALUE_TYPE_TIMESTAMP = GDA_TYPE_TIMESTAMP;
 */
 
 
-
+#if 0
 int value_compare_ext(const Glib::ValueBase& value1, const Glib::ValueBase& value2)
 {
   return gda_value_compare_ext(value1.gobj(), value2.gobj());
@@ -564,6 +565,7 @@ bool value_equal(const Glib::ValueBase& value1, const Glib::ValueBase& value2)
   int test = gda_value_compare(value1.gobj(), value2.gobj());
   return test == 0;
 }
+#endif
 
 
 
